@@ -7,14 +7,16 @@ import re
 
 class RequestsHandler(Session):
     def __init__(self, puser=None, set_proxy=True, proxy_generator=None, retry=3,
-                 pool_maxsize=10000, proxy_type: tuple = None, **kwargs):
+                 pool_maxsize=10000, proxy_type: dict = None, **kwargs):
         super(RequestsHandler, self).__init__()
         retry_strategy = Retry(total=retry, **kwargs)
         adapter = adapters.HTTPAdapter(max_retries=retry_strategy, pool_maxsize=pool_maxsize)
+        self.__proxy_generator = proxy_generator
+        self.__proxy_type = proxy_type
         self.__p = puser or {}
         if set_proxy:
-            self.proxies.update(RequestsConf.random_proxy(
-                self.__p.get('proxy'), proxy_generator=proxy_generator, proxy_type=proxy_type))
+            proxy_args = dict(proxy_generator=self.__proxy_generator, proxy_type=self.__proxy_type)
+            self.proxies.update(RequestsConf.random_proxy(self.__p.get('proxy'), **proxy_args))
         if puser:
             self.headers.update(RequestsConf.random_headers(self.__p.get('headers')))
             self.cookies.update(RequestsConf.random_cookies(self.__p.get('cookies')))
@@ -23,14 +25,24 @@ class RequestsHandler(Session):
         self.mount("https://", adapter)
         self.mount("http://", adapter)
 
-    def puser_update(self, puser: dict, proxy_type: tuple = None):
+    def puser_update(self, puser: dict, proxy_type: dict = None):
         self.proxies.update(RequestsConf.random_proxy(puser.get('proxy'), proxy_type=proxy_type))
         self.headers.update(RequestsConf.random_headers(puser.get('headers')))
         self.cookies.update(RequestsConf.random_cookies(puser.get('cookies')))
+        return self
 
-    def puser_reset(self, puser: dict):
+    def puser_reset(self, puser: dict, proxy_type: dict = None):
         [i.clear() for i in (self.proxies, self.headers, self.cookies)]
-        self.puser_update(puser)
+        return self.puser_update(puser, proxy_type=proxy_type)
+
+    def random_proxy(self):
+        proxy_args = dict(proxy_generator=self.__proxy_generator, proxy_type=self.__proxy_type)
+        if self.__proxy_generator:
+            self.proxies.clear()
+            self.proxies.update(RequestsConf.random_proxy(self.__p.get('proxy'), **proxy_args))
+            return self
+        else:
+            raise ValueError(f'The proxy_generator is not set.')
 
     @staticmethod
     def xpath(content: bytes, xpath: str):
