@@ -37,7 +37,7 @@ def test_random_cookies(func, cookie=None, set_new=True):
     print(RequestsConf.random_cookies(cookies=cookie, set_new=set_new))
 
 
-def test_random_proxy(func, proxy=None, proxy_type: tuple = None):
+def test_random_proxy(func, proxy=None, proxy_type: dict = None):
     test_proxies(func)
     print(RequestsConf.random_proxy(proxy=proxy, proxy_type=proxy_type))
 
